# libprimeiroprojeto
Módulo para exemplificar a criação de projetos Python

Aprendendo a contribuir com projetos open source

[![Build Status](https://travis-ci.org/DanielEliaSimoes/libprimeiroprojeto.svg?branch=master)](https://travis-ci.org/DanielEliaSimoes/libprimeiroprojeto)
[![Updates](https://pyup.io/repos/github/DanielEliaSimoes/libprimeiroprojeto/shield.svg)](https://pyup.io/repos/github/DanielEliaSimoes/libprimeiroprojeto/)
[![Python 3](https://pyup.io/repos/github/DanielEliaSimoes/libprimeiroprojeto/python-3-shield.svg)](https://pyup.io/repos/github/DanielEliaSimoes/libprimeiroprojeto/)
